@@ -7,15 +7,18 @@ from typing import List
 from boto3 import __version__ as boto3_version
 from boto3.session import Session
 
-from mypy_boto3_builder.cli_parser import parse_args
+from mypy_boto3_builder.cli_parser import Namespace, parse_args
 from mypy_boto3_builder.constants import BOTO3_STUBS_NAME, DUMMY_REGION, MODULE_NAME, PYPI_NAME
 from mypy_boto3_builder.jinja_manager import JinjaManager
 from mypy_boto3_builder.logger import get_logger
 from mypy_boto3_builder.service_name import ServiceName, ServiceNameCatalog
+from mypy_boto3_builder.utils.strings import get_anchor_link
 from mypy_boto3_builder.writers.processors import (
     process_boto3_stubs,
+    process_boto3_stubs_docs,
     process_master,
     process_service,
+    process_service_docs,
 )
 
 
@@ -24,7 +27,7 @@ def main() -> None:
     Main entrypoint for builder.
     """
     args = parse_args(sys.argv[1:])
-    logger = get_logger(verbose=args.debug, panic=args.panic)
+    logger = get_logger(level=args.log_level)
     session = Session(region_name=DUMMY_REGION)
     args.output_path.mkdir(exist_ok=True)
     service_names: List[ServiceName] = []
@@ -60,10 +63,30 @@ def main() -> None:
         boto3_version=boto3_version,
         build_version=build_version,
         builder_version=args.builder_version,
+        get_anchor_link=get_anchor_link,
+        render_docstrings=True,
     )
 
     logger.info(f"Bulding version {build_version}")
 
+    if args.generate_docs:
+        generate_docs(args, service_names, session)
+    else:
+        generate_stubs(args, service_names, session)
+
+    logger.info("Completed")
+
+
+def generate_stubs(args: Namespace, service_names: List[ServiceName], session: Session) -> None:
+    """
+    Generate service and master stubs.
+
+    Arguments:
+        args -- Config namespace
+        service_names -- Enabled service names
+        session -- Botocore session
+    """
+    logger = get_logger()
     if not args.skip_services:
         total_str = f"{len(service_names)}"
         for index, service_name in enumerate(service_names):
@@ -94,7 +117,36 @@ def main() -> None:
             generate_setup=not args.installed,
         )
 
-    logger.info("Completed")
+
+def generate_docs(args: Namespace, service_names: List[ServiceName], session: Session) -> None:
+    """
+    Generate service and master docs.
+
+    Arguments:
+        args -- Config namespace
+        service_names -- Enabled service names
+        session -- Botocore session
+    """
+    logger = get_logger()
+    if not args.skip_services:
+        total_str = f"{len(service_names)}"
+        for index, service_name in enumerate(service_names):
+            service_name.boto3_version = service_name.LATEST
+            current_str = f"{{:0{len(total_str)}}}".format(index + 1)
+            logger.info(f"[{current_str}/{total_str}] Generating {service_name.module_name} module")
+            process_service_docs(
+                session=session,
+                output_path=args.output_path,
+                service_name=service_name,
+            )
+
+    if not args.skip_master:
+        logger.info(f"Generating {BOTO3_STUBS_NAME} module")
+        process_boto3_stubs_docs(
+            session,
+            args.output_path,
+            service_names,
+        )
 
 
 if __name__ == "__main__":
