@@ -18,6 +18,7 @@ from botocore.model import (
 )
 from botocore.response import StreamingBody
 from botocore.session import Session as BotocoreSession
+
 from mypy_boto3_builder.import_helpers.import_string import ImportString
 from mypy_boto3_builder.logger import get_logger
 from mypy_boto3_builder.service_name import ServiceName, ServiceNameCatalog
@@ -316,10 +317,12 @@ class ShapeParser:
                 attr_name in required,
             )
         if shape.name.endswith("Output"):
+            for attribute in typed_dict.children:
+                attribute.required = True
             typed_dict.add_attribute(
                 "ResponseMetadata",
                 self.response_metadata_typed_dict,
-                False,
+                True,
             )
         return typed_dict
 
