@@ -4,6 +4,7 @@ Boto3 ServiceResource or Resource collection.
 from typing import Set
 
 from mypy_boto3_builder.import_helpers.import_string import ImportString
+from mypy_boto3_builder.service_name import ServiceName
 from mypy_boto3_builder.structures.class_record import ClassRecord
 from mypy_boto3_builder.type_annotations.external_import import ExternalImport
 from mypy_boto3_builder.type_annotations.fake_annotation import FakeAnnotation
@@ -19,13 +20,12 @@ class Collection(ClassRecord):
         name: str,
         attribute_name: str,
         parent_name: str,
+        service_name: ServiceName,
         type_annotation: FakeAnnotation,
-        docstring: str = "",
     ):
         super().__init__(
             name=name,
             use_alias=True,
-            docstring=docstring,
             bases=[
                 ExternalImport(
                     source=ImportString("boto3", "resources", "collection"),
@@ -33,10 +33,29 @@ class Collection(ClassRecord):
                 )
             ],
         )
+        self.service_name = service_name
         self.attribute_name = attribute_name
         self.parent_name = parent_name
         self.type_annotation = type_annotation
 
+    @property
+    def boto3_doc_link(self) -> str:
+        return self.service_name.get_boto3_doc_link(self.parent_name, self.name)
+
+    @property
+    def docstring(self) -> str:
+        doc_link = self.service_name.get_doc_link(
+            "service_resource",
+            f"{self.service_name.class_name}ServiceResource",
+            self.attribute_name,
+        )
+        return (
+            "[Show boto3 documentation]"
+            f"({self.boto3_doc_link})\n"
+            "[Show boto3-stubs documentation]"
+            f"({doc_link})"
+        )
+
     def get_types(self) -> Set[FakeAnnotation]:
         types = super().get_types()
         types.update(self.type_annotation.get_types())
